# eric7.Project.NewDirectoryDialog

Module implementing a dialog to enter the data for a new project sub-directory.

### Global Attributes

None

### Classes

NewDirectoryDialog | Class implementing a dialog to enter the data for a new project sub-directory.

### Functions

None

## NewDirectoryDialog

Class implementing a dialog to enter the data for a new project sub-directory.

### Derived from

QDialog

### Class Attributes

None

### Class Methods

None

### Methods

NewDirectoryDialog | Constructor
getDirectory | Public method to get the entered directory.

### Static Methods

None

#### NewDirectoryDialog (Constructor)

NewDirectoryDialog(title=None, label=None, mode=EricPathPickerModes.DIRECTORY_MODE, strPath=None, defaultDirectory=None, remote=False, parent=None, )

Constructor

title (str (optional))
  title of the dialog (defaults to None)
label (str (optional))
  text to be shown above the directory path picker (defaults to None)
mode (EricPathPickerModes (optional))
  mode of the path picker (defaults to EricPathPickerModes.DIRECTORY_MODE)
strPath (str (optional))
  initial path to be shown (defaults to None)
defaultDirectory (str (optional))
  default directory of the path picker selection dialog (defaults to None)
remote (bool (optional))
  flag indicating the remote mode (defaults to False)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### NewDirectoryDialog.getDirectory

getDirectory()

Public method to get the entered directory.

Return:
  tuple containing the entered directory and a flag indicating to add that directory to the project

Return Type:
  tuple of (str, bool)

Up